# IMPORTS:
import os
import sys
import re
import time
import random
import json
import requests
from Config import colors

###################
### Goobler 2022 ##
###################
# Scripts made by Eric #

# PURE CLASSES:

#class colors:
  #HEADER = '\033[95m'
  #OKBLUE = '\033[94m'
  #OKCYAN = '\033[96m'
  #OKGREEN = '\033[92m'
  #WARNING = '\033[93m'
  #FAIL = '\033[91m'
  #ENDC = '\033[0m'
  #BOLD = '\033[1m'
  #UNDERLINE = '\033[4m'

# PURE FUNCS:

def start(tkn):
  resp = requests.get("https://goobl2.ericplayzyt.repl.co/api/get_name_using_auth", {"auth": f"{tkn}"}).json()
  print(f"Starting {resp['user_name']}...")
  resp2 = requests.post("https://goobl2.ericplayzyt.repl.co/api/login/bot_account", {"auth": f"{tkn}"}).json()
  print(resp['user_name'] + "has logged in.")

def Application(client_id=None, token=None):
  if token == None:
    print(colors._FAIL + colors._BOLD + colors._UNDERLINE + "[GooblerAPI] You cannot execute 'MakeApplication' without the positional arguments, token. Remember, the token is the admin password to your application.")


from setuptools import setup
from setuptools import find_packages
###################
### Goobler 2023 ##
###################
# Scripts made by Eric #


setup(
  # the name must match the folder name 'GooblerPKG'
        name="GooblerPKG", 
        version="2.0.20",
        author="Goobler",
        author_email="<admin@goobler.epizy.com>",
        description="The Goobler Python API",
        long_description="Goobler's python API package which you may host your bot on!",
        packages=find_packages(),
        install_requires=['requests', ''], # add any additional packages that 
        # needs to be installed along with your package. Eg: 'caer'
        
        keywords=['python', 'api'],
        classifiers= [
            "Development Status :: 3 - Alpha",
            "Intended Audience :: Education",
            "Programming Language :: Python :: 2",
            "Programming Language :: Python :: 3",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft :: Windows",
        ]
)



###################
### Goobler 2023 ##
###################
# Scripts made by Eric #

import requests

print("[Process] INITIALIZED")

class ctx: 
    def __init__(self):
        pass

    def send_message(self, message, sender="My Bot"):
        resp = requests.get("https://goobl2.ericplayzyt.repl.co/api/messaging/send_message/s/minecraft", headers={"message": message, "sent_by": sender})

def command(function, **kwargs):
    return function and ctx